@@ -2,7 +2,7 @@
 EXTREME TUXRACER
 
 Copyright (C) 1999-2001 Jasmin F. Patry (Tuxracer)
-Copyright (C) 2010 Extreme Tuxracer Team
+Copyright (C) 2010 Extreme Tux Racer Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@ GNU General Public License for more details.
 #include "game_ctrl.h"
 #include "score.h"
 #include "ogl.h"
+#include "translation.h"
 #include <iostream>
 
 TVector2i cursor_pos(0, 0);
@@ -33,8 +34,10 @@ TVector2i cursor_pos(0, 0);
 CWinsys Winsys;
 
 CWinsys::CWinsys()
-	: sfmlRenders(false)
-	, auto_resolution(800, 600) {
+	: numJoysticks(0)
+	, sfmlRenders(false)
+	, auto_resolution(800, 600)
+	, scale(1.f) {
 	for (unsigned int i = 0; i < sf::Joystick::Count; i++) {
 		if (sf::Joystick::isConnected(i))
 			numJoysticks++;
@@ -55,15 +58,15 @@ CWinsys::CWinsys()
 	resolutions[9] = TScreenRes(1680, 1050);
 }
 
-const TScreenRes& CWinsys::GetResolution(size_t idx) const {
+const TScreenRes& CWinsys::GetResolution(std::size_t idx) const {
 	if (idx >= NUM_RESOLUTIONS || (idx == 0 && !param.fullscreen)) return auto_resolution;
 	return resolutions[idx];
 }
 
-string CWinsys::GetResName(size_t idx) const {
+std::string CWinsys::GetResName(std::size_t idx) const {
 	if (idx >= NUM_RESOLUTIONS) return "800 x 600";
-	if (idx == 0) return ("auto");
-	string line = Int_StrN(resolutions[idx].width);
+	if (idx == 0) return (Trans.Text(110));
+	std::string line = Int_StrN(resolutions[idx].width);
 	line += " x " + Int_StrN(resolutions[idx].height);
 	return line;
 }
@@ -73,7 +76,7 @@ float CWinsys::CalcScreenScale() const {
 	else return (resolution.height / 768.f);
 }
 
-void CWinsys::SetupVideoMode(const TScreenRes& resolution_) {
+void CWinsys::SetupVideoMode(const TScreenRes& res) {
 	int bpp = 32;
 	switch (param.bpp_mode) {
 		case 16:
@@ -90,7 +93,7 @@ void CWinsys::SetupVideoMode(const TScreenRes& resolution_) {
 	if (param.fullscreen)
 		style |= sf::Style::Fullscreen;
 
-	resolution = resolution_;
+	resolution = res;
 
 	ResetRenderMode();
 
@@ -102,12 +105,17 @@ void CWinsys::SetupVideoMode(const TScreenRes& resolution_) {
 	window.create(sf::VideoMode(resolution.width, resolution.height, bpp), WINDOW_TITLE, style, ctx);
 	if (param.framerate)
 		window.setFramerateLimit(param.framerate);
+#ifdef _WIN32
+	HICON icon = LoadIcon(GetModuleHandle(NULL), (LPCWSTR)IDI_APPLICATION);
+	SendMessageW(window.getSystemHandle(), WM_SETICON, ICON_BIG, (LPARAM)icon);
+	SendMessageW(window.getSystemHandle(), WM_SETICON, ICON_SMALL, (LPARAM)icon);
+#endif
 
 	scale = CalcScreenScale();
-	if (param.use_quad_scale) scale = sqrt(scale);
+	if (param.use_quad_scale) scale = std::sqrt(scale);
 }
 
-void CWinsys::SetupVideoMode(size_t idx) {
+void CWinsys::SetupVideoMode(std::size_t idx) {
 	SetupVideoMode(GetResolution(idx));
 }
 
@@ -132,27 +140,27 @@ void CWinsys::Quit() {
 
 void CWinsys::Terminate() {
 	Quit();
-	exit(0);
+	std::exit(0);
 }
 
 void CWinsys::PrintJoystickInfo() const {
 	if (numJoysticks == 0) {
-		cout << "No joystick found\n";
+		std::cout << "No joystick found\n";
 		return;
 	}
-	cout << '\n';
+	std::cout << '\n';
 	for (unsigned int i = 0; i < numJoysticks; i++) {
-		cout << "Joystick " << i << '\n';
+		std::cout << "Joystick " << i << '\n';
 		int buttons = sf::Joystick::getButtonCount(i);
-		cout << "Joystick has " << buttons << " button" << (buttons == 1 ? "" : "s") << '\n';
-		cout << "Axes: ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::R)) cout << "R ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::U)) cout << "U ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::V)) cout << "V ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::X)) cout << "X ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::Y)) cout << "Y ";
-		if (sf::Joystick::hasAxis(i, sf::Joystick::Z)) cout << "Z ";
-		cout << '\n';
+		std::cout << "Joystick has " << buttons << " button" << (buttons == 1 ? "" : "s") << '\n';
+		std::cout << "Axes: ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::R)) std::cout << "R ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::U)) std::cout << "U ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::V)) std::cout << "V ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::X)) std::cout << "X ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::Y)) std::cout << "Y ";
+		if (sf::Joystick::hasAxis(i, sf::Joystick::Z)) std::cout << "Z ";
+		std::cout << '\n';
 	}
 }
 
@@ -162,14 +170,14 @@ void CWinsys::TakeScreenshot() const {
 	tex.update(window);
 	sf::Image img = tex.copyToImage();
 
-	string path = param.screenshot_dir;
+	std::string path = param.screenshot_dir;
 
 #if !defined (OS_WIN32_MINGW) && !defined (OS_WIN32_MSC)
-        const char *cpath = path.c_str();
+	const char *cpath = path.c_str();
 
-        if (!DirExists(cpath)) {
+	if (!DirExists(cpath)) {
 		mkdir(cpath, 0775);
-        }
+	}
 #endif /* WIN32 */
 
 	path += SEP;
